# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_stdio.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10grpc_stdio.proto\x12\x06plugin\x1a\x1bgoogle/protobuf/empty.proto"u\n\tStdioData\x12*\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\x19.plugin.StdioData.Channel\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c".\n\x07\x43hannel\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06STDOUT\x10\x01\x12\n\n\x06STDERR\x10\x02\x32G\n\tGRPCStdio\x12:\n\x0bStreamStdio\x12\x16.google.protobuf.Empty\x1a\x11.plugin.StdioData0\x01\x42\nZ\x08./pluginb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "grpc_stdio_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\010./plugin"
    _globals["_STDIODATA"]._serialized_start = 57
    _globals["_STDIODATA"]._serialized_end = 174
    _globals["_STDIODATA_CHANNEL"]._serialized_start = 128
    _globals["_STDIODATA_CHANNEL"]._serialized_end = 174
    _globals["_GRPCSTDIO"]._serialized_start = 176
    _globals["_GRPCSTDIO"]._serialized_end = 247
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import int_connector_lib.proto.source_pb2 as source__pb2


class BaseSourceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Start = channel.unary_unary(
            "/proto.BaseSource/Start",
            request_serializer=source__pb2.StartRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.Stop = channel.unary_unary(
            "/proto.BaseSource/Stop",
            request_serializer=source__pb2.StopRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.GetStatus = channel.unary_unary(
            "/proto.BaseSource/GetStatus",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=source__pb2.StatusMessage.FromString,
        )
        self.GetDetails = channel.unary_unary(
            "/proto.BaseSource/GetDetails",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=source__pb2.DetailsMessage.FromString,
        )
        self.CheckConfig = channel.unary_unary(
            "/proto.BaseSource/CheckConfig",
            request_serializer=source__pb2.ConfigMessage.SerializeToString,
            response_deserializer=source__pb2.ValidationMessage.FromString,
        )


class BaseSourceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Start(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Stop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CheckConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_BaseSourceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Start": grpc.unary_unary_rpc_method_handler(
            servicer.Start,
            request_deserializer=source__pb2.StartRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "Stop": grpc.unary_unary_rpc_method_handler(
            servicer.Stop,
            request_deserializer=source__pb2.StopRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "GetStatus": grpc.unary_unary_rpc_method_handler(
            servicer.GetStatus,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=source__pb2.StatusMessage.SerializeToString,
        ),
        "GetDetails": grpc.unary_unary_rpc_method_handler(
            servicer.GetDetails,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=source__pb2.DetailsMessage.SerializeToString,
        ),
        "CheckConfig": grpc.unary_unary_rpc_method_handler(
            servicer.CheckConfig,
            request_deserializer=source__pb2.ConfigMessage.FromString,
            response_serializer=source__pb2.ValidationMessage.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("proto.BaseSource", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class BaseSource(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Start(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.BaseSource/Start",
            source__pb2.StartRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Stop(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.BaseSource/Stop",
            source__pb2.StopRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetStatus(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.BaseSource/GetStatus",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            source__pb2.StatusMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetDetails(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.BaseSource/GetDetails",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            source__pb2.DetailsMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CheckConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.BaseSource/CheckConfig",
            source__pb2.ConfigMessage.SerializeToString,
            source__pb2.ValidationMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class SourceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetData = channel.unary_unary(
            "/proto.Source/GetData",
            request_serializer=source__pb2.DataMessage.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class SourceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SourceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetData": grpc.unary_unary_rpc_method_handler(
            servicer.GetData,
            request_deserializer=source__pb2.DataMessage.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("proto.Source", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Source(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetData(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Source/GetData",
            source__pb2.DataMessage.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class StreamingSourceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartStream = channel.unary_unary(
            "/proto.StreamingSource/StartStream",
            request_serializer=source__pb2.DataMessage.SerializeToString,
            response_deserializer=source__pb2.StartedStreamMessage.FromString,
        )
        self.StopStream = channel.unary_unary(
            "/proto.StreamingSource/StopStream",
            request_serializer=source__pb2.StopStreamMessage.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class StreamingSourceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StopStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StreamingSourceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StartStream": grpc.unary_unary_rpc_method_handler(
            servicer.StartStream,
            request_deserializer=source__pb2.DataMessage.FromString,
            response_serializer=source__pb2.StartedStreamMessage.SerializeToString,
        ),
        "StopStream": grpc.unary_unary_rpc_method_handler(
            servicer.StopStream,
            request_deserializer=source__pb2.StopStreamMessage.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("proto.StreamingSource", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StreamingSource(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartStream(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.StreamingSource/StartStream",
            source__pb2.DataMessage.SerializeToString,
            source__pb2.StartedStreamMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StopStream(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.StreamingSource/StopStream",
            source__pb2.StopStreamMessage.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



import logging
import typing
from collections import defaultdict

import grpc
import pydantic

from int_connector_lib import protobuf
from int_connector_lib.broker import Broker
from int_connector_lib.config import RunConfig, SourceConfig
from int_connector_lib.manager import Manager
from int_connector_lib.proto import (
    source_pb2,
    source_pb2_grpc,
)

P = typing.ParamSpec("P")


class BaseSource(source_pb2_grpc.BaseSourceServicer):
    """Implement grpc BaseSource for basic Source information."""

    def __init__(  # noqa: PLR0913
        self: typing.Self,
        logger: logging.Logger,
        run_config_class: type[RunConfig],
        source_config_class: type[SourceConfig] | None,
        source_type: str,
        source_version: str,
    ) -> None:
        self.logger = logger
        self.id = ""
        self.name = ""
        self.status = source_pb2.STATUS_UNKNOWN
        self.source_type = source_type
        self.source_version = source_version
        self._run_config_class = run_config_class
        self._source_config_class = source_config_class
        self.sources = {}

    def CheckConfig(
        self: typing.Self,
        request: source_pb2.ConfigMessage,
        context: grpc.ServicerContext,
    ) -> source_pb2.ValidationMessage:
        """Handle rpc.CheckConfig call."""
        self.logger.debug("CheckConfig called!")
        errors = defaultdict(list)
        for i, source in enumerate(request.SourcesConfig):
            self.logger.info(type(source))
            self.logger.info(source)
            try:
                self.sources[source.id] = self._source_config_class.from_source(source)
            except pydantic.ValidationError as e:
                for err in e.errors():
                    loc = ".".join(err["loc"])
                    errors[f"sources.{i}.{loc}"].append(err["msg"])

        for i, run in enumerate(request.RunsConfig):
            try:
                self._run_config_class.from_struct(run.source)
            except pydantic.ValidationError as e:
                for err in e.errors():
                    loc = ".".join(err["loc"])
                    errors[f"runs.{i}.config.{loc}"].append(err["msg"])

        if errors:
            return source_pb2.ValidationMessage(
                valid=False,
                errors=[
                    source_pb2.ValidationError(
                        location=location,
                        message=error,
                    )
                    for location, errors_ in errors.items()
                    for error in errors_
                ],
            )
        return source_pb2.ValidationMessage(valid=True)

    def Start(self: typing.Self, request: source_pb2.StartRequest, context: grpc.ServicerContext) -> protobuf.Empty:
        """Handle rpc.Start call."""
        self.logger.debug("Start called!")
        self.id = request.id
        self.name = request.name
        self.status = source_pb2.Status.STATUS_RUNNING
        return protobuf.Empty()

    def Stop(self: typing.Self, request: source_pb2.StopRequest, context: grpc.ServicerContext) -> protobuf.Empty:
        """Handle rpc.Stop call."""
        self.logger.debug("Stop called!")
        self.status = source_pb2.Status.STATUS_READY
        return protobuf.Empty()

    def GetStatus(
        self: typing.Self,
        request: protobuf.Empty,
        context: grpc.ServicerContext,
    ) -> source_pb2.StatusMessage:
        """Handle rpc.GetStatus call."""
        self.logger.debug("GetStatus called!")
        return source_pb2.StatusMessage(status=self.status)

    def GetDetails(
        self: typing.Self,
        request: protobuf.Empty,
        context: grpc.ServicerContext,
    ) -> source_pb2.DetailsMessage:
        """Handle rpc.GetDetails call."""
        self.logger.debug("Details called!")
        return source_pb2.DetailsMessage(id=self.id, type=self.source_type, version=self.source_version, name=self.name)


class Source(BaseSource):
    """Implement grpc Source to handle data transfer for plugin."""

    streaming: bool = False

    def __init__(self: typing.Self, broker: Broker, **kwargs: P.kwargs) -> None:
        super().__init__(**kwargs)
        self.broker = broker

    def get_data(
        self: typing.Self,
        manager: Manager,
        config: RunConfig,
    ) -> protobuf.Empty:
        """Perform actual get data based on configuration and send to provided Manager."""
        raise NotImplementedError

    def GetData(
        self: typing.Self,
        request: source_pb2.DataMessage,
        context: grpc.ServicerContext,
    ) -> protobuf.Empty:
        """Handle rpc.GetData call."""
        self.logger.debug("Data called!")
        channel = self.broker.Dial(request.manager)
        mgr = Manager(channel)

        config = self._run_config_class.from_struct(request.source)

        return self.get_data(mgr, config)


class StreamingSource(BaseSource):
    """Implement grpc StreamingSource to handle streaming data transfer for plugin."""

    streaming: bool = True

    def __init__(self: typing.Self, broker: Broker, **kwargs: P.kwargs) -> None:
        super().__init__(**kwargs)
        self.broker = broker
        self.streams = {}

    def start_stream(
        self: typing.Self,
        manager: Manager,
        config: RunConfig,
    ) -> str:
        """Connect to data source and provide data updates to Manager."""
        raise NotImplementedError

    def StartStream(
        self: typing.Self,
        request: source_pb2.DataMessage,
        context: grpc.ServicerContext,
    ) -> source_pb2.StartedStreamMessage:
        """Handle rpc.StartStream call."""
        self.logger.debug("StartStream called!")
        channel = self.broker.Dial(request.manager)
        mgr = Manager(channel)

        config = self._run_config_class.from_struct(request.source)

        stream_id = self.start_stream(mgr, config)

        return source_pb2.StartedStreamMessage(
            ID=stream_id,
        )

    def stop_stream(
        self: typing.Self,
        stream_id: str,
    ) -> protobuf.Empty:
        """Stop a running stream."""
        raise NotImplementedError

    def StopStream(
        self: typing.Self,
        request: source_pb2.StopStreamMessage,
        context: grpc.ServicerContext,
    ) -> protobuf.Empty:
        """Handle rpc.StopStream call."""
        self.logger.debug("StopStream called!")
        return self.stop_stream(stream_id=request.ID)



import logging
import typing

import pydantic
from google.protobuf.struct_pb2 import Struct

from int_connector_lib.proto.source_pb2 import DataSource

T = typing.TypeVar("T", bound=pydantic.BaseModel)
logger = logging.getLogger(__name__)


def nested_struct_to_nested_dict(struct: Struct) -> dict:
    """Convert a Struct into a dict, handling nested Struct data."""
    ret = {}
    for k, v in struct.items():
        if isinstance(v, Struct):
            v = nested_struct_to_nested_dict(v)  # noqa: PLW2901
        ret[k] = v
    return ret


class RunConfig(pydantic.BaseModel):
    """Base config model to handle grpc config structs."""

    @classmethod
    def from_struct(cls: type[T], struct: Struct) -> T:
        """Convert google protobuf.Struct to a config object."""
        data = nested_struct_to_nested_dict(struct)
        return cls(**data)


class SourceConfig(pydantic.BaseModel):
    """Base class for Source configs."""

    id: str
    name: str
    config: dict

    @classmethod
    def from_source(cls: type[T], source: DataSource) -> T:
        """Convert google protobuf.Struct to a config object."""
        config = nested_struct_to_nested_dict(source.config)
        return cls(id=source.id, name=source.name, config=config)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_controller.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15grpc_controller.proto\x12\x06plugin"\x07\n\x05\x45mpty2:\n\x0eGRPCController\x12(\n\x08Shutdown\x12\r.plugin.Empty\x1a\r.plugin.EmptyB\nZ\x08./pluginb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "grpc_controller_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\010./plugin"
    _globals["_EMPTY"]._serialized_start = 33
    _globals["_EMPTY"]._serialized_end = 40
    _globals["_GRPCCONTROLLER"]._serialized_start = 42
    _globals["_GRPCCONTROLLER"]._serialized_end = 100
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import int_connector_lib.proto.manager_pb2 as manager__pb2


class ManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendData = channel.unary_unary(
            "/proto.Manager/SendData",
            request_serializer=manager__pb2.SendDataRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.SendFile = channel.unary_unary(
            "/proto.Manager/SendFile",
            request_serializer=manager__pb2.SendFileRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.SendJSONSchema = channel.unary_unary(
            "/proto.Manager/SendJSONSchema",
            request_serializer=manager__pb2.SendJSONSchemaRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.SendColumnsSchema = channel.unary_unary(
            "/proto.Manager/SendColumnsSchema",
            request_serializer=manager__pb2.SendColumnsSchemaRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ReportDataUnitState = channel.unary_unary(
            "/proto.Manager/ReportDataUnitState",
            request_serializer=manager__pb2.ReportDataUnitStateRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class ManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SendFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SendJSONSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SendColumnsSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReportDataUnitState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SendData": grpc.unary_unary_rpc_method_handler(
            servicer.SendData,
            request_deserializer=manager__pb2.SendDataRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "SendFile": grpc.unary_unary_rpc_method_handler(
            servicer.SendFile,
            request_deserializer=manager__pb2.SendFileRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "SendJSONSchema": grpc.unary_unary_rpc_method_handler(
            servicer.SendJSONSchema,
            request_deserializer=manager__pb2.SendJSONSchemaRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "SendColumnsSchema": grpc.unary_unary_rpc_method_handler(
            servicer.SendColumnsSchema,
            request_deserializer=manager__pb2.SendColumnsSchemaRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ReportDataUnitState": grpc.unary_unary_rpc_method_handler(
            servicer.ReportDataUnitState,
            request_deserializer=manager__pb2.ReportDataUnitStateRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("proto.Manager", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Manager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendData(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Manager/SendData",
            manager__pb2.SendDataRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SendFile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Manager/SendFile",
            manager__pb2.SendFileRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SendJSONSchema(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Manager/SendJSONSchema",
            manager__pb2.SendJSONSchemaRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SendColumnsSchema(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Manager/SendColumnsSchema",
            manager__pb2.SendColumnsSchemaRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ReportDataUnitState(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Manager/ReportDataUnitState",
            manager__pb2.ReportDataUnitStateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



import typing
from concurrent import futures

import grpc
from grpc_health.v1 import health_pb2_grpc

from int_connector_lib.broker import Broker
from int_connector_lib.health import HealthServicer
from int_connector_lib.proto import (
    grpc_broker_pb2_grpc,
    source_pb2_grpc,
)
from int_connector_lib.source import BaseSource, Source, StreamingSource


class Server:
    """Wrapper for grpc.Server functionality."""

    def __init__(self: typing.Self, max_workers: int) -> None:
        self._server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))

    def add_base_source_servicer(self: typing.Self, base_source: BaseSource) -> None:
        """Register a BaseSourceServicer against the server."""
        source_pb2_grpc.add_BaseSourceServicer_to_server(base_source, self._server)

    def add_source_servicer(self: typing.Self, source: Source) -> None:
        """Register a SourceServicer against the server."""
        source_pb2_grpc.add_SourceServicer_to_server(source, self._server)

    def add_streaming_source_servicer(self: typing.Self, source: StreamingSource) -> None:
        """Register a SourceServicer against the server."""
        source_pb2_grpc.add_StreamingSourceServicer_to_server(source, self._server)

    def add_broker_servicer(self: typing.Self, broker: Broker) -> None:
        """Register a GRPCBrokerServicer against the server."""
        grpc_broker_pb2_grpc.add_GRPCBrokerServicer_to_server(broker, self._server)

    def add_health_servicer(self: typing.Self, health: HealthServicer) -> None:
        """Register a HealthServicer against the server."""
        health_pb2_grpc.add_HealthServicer_to_server(health, self._server)

    def __getattr__(self, attr: str):  # noqa: ANN101, ANN204
        """Expose internal server methods."""
        return getattr(self._server, attr)
